summaryrefslogtreecommitdiffstats
path: root/build-bundle.sh
diff options
context:
space:
mode:
authorgabrix73 <gabriel1@frozenstar.info>2026-04-12 14:49:49 +0200
committergabrix73 <gabriel1@frozenstar.info>2026-04-12 14:49:49 +0200
commitbb189dd1e7cc14900e03a72403752e6aa5276d8c (patch)
treebdf857d7101e8889c33077c55819227eaff675bb /build-bundle.sh
parenta7a7d3fd4559015fbe02b2016c3f39379262d1c2 (diff)
downloadkhimera-bb189dd1e7cc14900e03a72403752e6aa5276d8c.tar.gz
khimera-bb189dd1e7cc14900e03a72403752e6aa5276d8c.tar.xz
khimera-bb189dd1e7cc14900e03a72403752e6aa5276d8c.zip
rename: Veilith -> Khimera across all files and documentation
Diffstat (limited to 'build-bundle.sh')
-rwxr-xr-xbuild-bundle.sh72
1 files changed, 36 insertions, 36 deletions
diff --git a/build-bundle.sh b/build-bundle.sh
index d848fd4..3ffcb3b 100755
--- a/build-bundle.sh
+++ b/build-bundle.sh
@@ -1,5 +1,5 @@
#!/bin/bash
# Veilith Portable - USB Bundle Builder
# Creates a complete multi-platform USB bundle
set -e
@@ -14,13 +14,13 @@ NC='\033[0m'
# Configuration
VERSION="0.9"
-BUNDLE_NAME="veilith-usb-v${VERSION}"
+BUNDLE_NAME="khimera-usb-v${VERSION}"
BUILD_DATE=$(date +%Y%m%d)
echo -e "${CYAN}"
echo "╔══════════════════════════════════════════════════════╗"
echo "║ ║"
-echo "║ VEILITH USB BUNDLE BUILDER v${VERSION} ║"
+echo "║ KHIMERA USB BUNDLE BUILDER v${VERSION} ║"
echo "║ Multi-Platform Portable Distribution ║"
echo "║ ║"
echo "╚══════════════════════════════════════════════════════╝"
@@ -54,19 +54,19 @@ echo ""
# Build Linux
echo -e "${BLUE}[1/2]${NC} Building Linux executable..."
echo " Target: Linux AMD64"
-echo " Output: $BUNDLE_NAME/Linux/veilith-linux"
+echo " Output: $BUNDLE_NAME/Linux/khimera-linux"
CGO_ENABLED=1 \
GOOS=linux \
GOARCH=amd64 \
go build \
-ldflags="-s -w -X main.Version=${VERSION} -X main.BuildDate=${BUILD_DATE}" \
- -o "$BUNDLE_NAME/Linux/veilith-linux" \
- ./veilith-main.go
+ -o "$BUNDLE_NAME/Linux/khimera-linux" \
+ ./khimera-main.go
if [ $? -eq 0 ]; then
- chmod +x "$BUNDLE_NAME/Linux/veilith-linux"
- SIZE=$(du -h "$BUNDLE_NAME/Linux/veilith-linux" | cut -f1)
+ chmod +x "$BUNDLE_NAME/Linux/khimera-linux"
+ SIZE=$(du -h "$BUNDLE_NAME/Linux/khimera-linux" | cut -f1)
echo -e "${GREEN}✓${NC} Linux build complete (${SIZE})"
else
echo -e "${RED}✗${NC} Linux build failed"
@@ -79,7 +79,7 @@ echo -e "${BLUE}[2/2]${NC} Building Windows executable..."
if command -v x86_64-w64-mingw32-gcc &> /dev/null; then
echo " Target: Windows AMD64"
- echo " Output: $BUNDLE_NAME/Windows/veilith.exe"
+ echo " Output: $BUNDLE_NAME/Windows/khimera.exe"
CGO_ENABLED=1 \
GOOS=windows \
@@ -87,11 +87,11 @@ if command -v x86_64-w64-mingw32-gcc &> /dev/null; then
CC=x86_64-w64-mingw32-gcc \
go build \
-ldflags="-s -w -H windowsgui -X main.Version=${VERSION} -X main.BuildDate=${BUILD_DATE}" \
- -o "$BUNDLE_NAME/Windows/veilith.exe" \
- ./veilith-main.go
+ -o "$BUNDLE_NAME/Windows/khimera.exe" \
+ ./khimera-main.go
if [ $? -eq 0 ]; then
- SIZE=$(du -h "$BUNDLE_NAME/Windows/veilith.exe" | cut -f1)
+ SIZE=$(du -h "$BUNDLE_NAME/Windows/khimera.exe" | cut -f1)
echo -e "${GREEN}✓${NC} Windows build complete (${SIZE})"
else
echo -e "${RED}✗${NC} Windows build failed"
@@ -123,10 +123,10 @@ To build Android APK:
3. Build APK:
cd ..
- fyne package -os android -appID com.veilith.portable
+ fyne package -os android -appID com.khimera.portable
4. Sign APK (optional):
- jarsigner -keystore veilith.keystore app.apk veilith
+ jarsigner -keystore khimera.keystore app.apk khimera
For more info: https://developer.fyne.io/started/mobile
EOF
@@ -138,7 +138,7 @@ echo -e "${YELLOW}[Documentation]${NC} Creating README..."
cat > "$BUNDLE_NAME/README.txt" << EOF
╔══════════════════════════════════════════════════════════════╗
║ ║
-║ VEILITH PORTABLE USB v${VERSION} ║
+║ KHIMERA PORTABLE USB v${VERSION} ║
║ Privacy-First P2P Messenger ║
║ Multi-Platform Edition ║
║ ║
@@ -147,10 +147,10 @@ cat > "$BUNDLE_NAME/README.txt" << EOF
BUILD DATE: ${BUILD_DATE}
═══════════════════════════════════════════════════════════════
- WHAT IS VEILITH PORTABLE?
+ WHAT IS KHIMERA PORTABLE?
═══════════════════════════════════════════════════════════════
-Veilith Portable is a zero-installation, privacy-first messenger
+Khimera Portable is a zero-installation, privacy-first messenger
that runs directly from USB drives on multiple platforms:
✓ Windows (x86_64)
@@ -168,14 +168,14 @@ No traces left on the host system.
LINUX / macOS:
1. Open terminal in this directory
2. Run: ./launcher
- 3. Or: cd Linux && ./veilith-linux
+ 3. Or: cd Linux && ./khimera-linux
WINDOWS:
1. Double-click: launcher.bat
- 2. Or: Double-click: Windows/veilith.exe
+ 2. Or: Double-click: Windows/khimera.exe
ANDROID:
- 1. Copy Android/veilith.apk to your phone
+ 1. Copy Android/khimera.apk to your phone
2. Enable "Unknown Sources" in settings
3. Install the APK
4. Launch from app drawer
@@ -185,15 +185,15 @@ ANDROID:
BUNDLE STRUCTURE
═══════════════════════════════════════════════════════════════
-veilith-usb-v${VERSION}/
+khimera-usb-v${VERSION}/
├── launcher # Smart launcher (Linux/Mac)
├── launcher.bat # Windows launcher
├── Windows/ # Windows executable
-│ └── veilith.exe
+│ └── khimera.exe
├── Linux/ # Linux executable
-│ └── veilith-linux
+│ └── khimera-linux
├── Android/ # Android APK
-│ └── veilith.apk
+│ └── khimera.apk
├── data/ # YOUR DATA (encrypted)
│ ├── identity.enc # Your cryptographic identity
│ └── contacts.enc # Your contact list
@@ -248,11 +248,11 @@ PRIVACY:
LINUX:
Permission denied?
chmod +x launcher
- chmod +x Linux/veilith-linux
+ chmod +x Linux/khimera-linux
WINDOWS:
Antivirus blocking?
- Add veilith.exe to exceptions
+ Add khimera.exe to exceptions
Won't start?
Right-click → Run as Administrator (one time)
@@ -266,7 +266,7 @@ ANDROID:
FIRST RUN
═══════════════════════════════════════════════════════════════
-On first run, Veilith will:
+On first run, Khimera will:
1. Create a new cryptographic identity
2. Ask for a passphrase to protect it
3. Save encrypted identity to data/identity.enc
@@ -282,9 +282,9 @@ On subsequent runs:
SUPPORT
═══════════════════════════════════════════════════════════════
- Website: https://veilith-messenger.org
- Email: support@veilith-messenger.org
- Security: security@veilith-messenger.org
+ Website: https://khimera-messenger.org
+ Email: support@khimera-messenger.org
+ Security: security@khimera-messenger.org
═══════════════════════════════════════════════════════════════
@@ -297,7 +297,7 @@ See docs/LICENSE.txt for licensing information.
Built: ${BUILD_DATE}
Version: ${VERSION}
-Veilith Portable - Privacy you can carry
+Khimera Portable - Privacy you can carry
EOF
echo -e "${GREEN}✓${NC} README created"
@@ -329,13 +329,13 @@ echo ""
echo -e "${YELLOW}[Summary]${NC} Bundle summary..."
echo "━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━"
-if [ -f "$BUNDLE_NAME/Linux/veilith-linux" ]; then
- LINUX_SIZE=$(du -h "$BUNDLE_NAME/Linux/veilith-linux" | cut -f1)
+if [ -f "$BUNDLE_NAME/Linux/khimera-linux" ]; then
+ LINUX_SIZE=$(du -h "$BUNDLE_NAME/Linux/khimera-linux" | cut -f1)
echo " Linux: ${LINUX_SIZE}"
fi
-if [ -f "$BUNDLE_NAME/Windows/veilith.exe" ]; then
- WINDOWS_SIZE=$(du -h "$BUNDLE_NAME/Windows/veilith.exe" | cut -f1)
+if [ -f "$BUNDLE_NAME/Windows/khimera.exe" ]; then
+ WINDOWS_SIZE=$(du -h "$BUNDLE_NAME/Windows/khimera.exe" | cut -f1)
echo " Windows: ${WINDOWS_SIZE}"
fi
@@ -380,5 +380,5 @@ echo "To distribute:"
echo " • Share ${BUNDLE_NAME}.zip (Windows users)"
echo " • Share ${BUNDLE_NAME}.tar.gz (Linux users)"
echo ""
-echo -e "${CYAN}Veilith Portable - Privacy you can carry${NC}"
+echo -e "${CYAN}Khimera Portable - Privacy you can carry${NC}"
echo ""
@@ -1,5 +1,5 @@
#!/bin/bash
-# Veilith Portable - USB Bundle Builder
+# Khimera Portable - USB Bundle Builder
# Creates a complete multi-platform USB bundle
set -e